

RegistryResults
=================================

.. currentmodule:: pyvo.registry.vao

.. autoclass:: RegistryResults
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~RegistryResults.size

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~RegistryResults.getrecord
      ~RegistryResults.getvalue

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: size

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: getrecord
   .. automethod:: getvalue

   
   